@@ -243,171 +243,191 @@ extern int yydebug;
     VAR_DNSTAP_LOG_CLIENT_RESPONSE_MESSAGES = 444, /* VAR_DNSTAP_LOG_CLIENT_RESPONSE_MESSAGES  */
     VAR_DNSTAP_LOG_FORWARDER_QUERY_MESSAGES = 445, /* VAR_DNSTAP_LOG_FORWARDER_QUERY_MESSAGES  */
     VAR_DNSTAP_LOG_FORWARDER_RESPONSE_MESSAGES = 446, /* VAR_DNSTAP_LOG_FORWARDER_RESPONSE_MESSAGES  */
-    VAR_RESPONSE_IP_TAG = 447,     /* VAR_RESPONSE_IP_TAG  */
-    VAR_RESPONSE_IP = 448,         /* VAR_RESPONSE_IP  */
-    VAR_RESPONSE_IP_DATA = 449,    /* VAR_RESPONSE_IP_DATA  */
-    VAR_HARDEN_ALGO_DOWNGRADE = 450, /* VAR_HARDEN_ALGO_DOWNGRADE  */
-    VAR_IP_TRANSPARENT = 451,      /* VAR_IP_TRANSPARENT  */
-    VAR_IP_DSCP = 452,             /* VAR_IP_DSCP  */
-    VAR_DISABLE_DNSSEC_LAME_CHECK = 453, /* VAR_DISABLE_DNSSEC_LAME_CHECK  */
-    VAR_IP_RATELIMIT = 454,        /* VAR_IP_RATELIMIT  */
-    VAR_IP_RATELIMIT_SLABS = 455,  /* VAR_IP_RATELIMIT_SLABS  */
-    VAR_IP_RATELIMIT_SIZE = 456,   /* VAR_IP_RATELIMIT_SIZE  */
-    VAR_RATELIMIT = 457,           /* VAR_RATELIMIT  */
-    VAR_RATELIMIT_SLABS = 458,     /* VAR_RATELIMIT_SLABS  */
-    VAR_RATELIMIT_SIZE = 459,      /* VAR_RATELIMIT_SIZE  */
-    VAR_OUTBOUND_MSG_RETRY = 460,  /* VAR_OUTBOUND_MSG_RETRY  */
-    VAR_MAX_SENT_COUNT = 461,      /* VAR_MAX_SENT_COUNT  */
-    VAR_MAX_QUERY_RESTARTS = 462,  /* VAR_MAX_QUERY_RESTARTS  */
-    VAR_RATELIMIT_FOR_DOMAIN = 463, /* VAR_RATELIMIT_FOR_DOMAIN  */
-    VAR_RATELIMIT_BELOW_DOMAIN = 464, /* VAR_RATELIMIT_BELOW_DOMAIN  */
-    VAR_IP_RATELIMIT_FACTOR = 465, /* VAR_IP_RATELIMIT_FACTOR  */
-    VAR_RATELIMIT_FACTOR = 466,    /* VAR_RATELIMIT_FACTOR  */
-    VAR_IP_RATELIMIT_BACKOFF = 467, /* VAR_IP_RATELIMIT_BACKOFF  */
-    VAR_RATELIMIT_BACKOFF = 468,   /* VAR_RATELIMIT_BACKOFF  */
-    VAR_SEND_CLIENT_SUBNET = 469,  /* VAR_SEND_CLIENT_SUBNET  */
-    VAR_CLIENT_SUBNET_ZONE = 470,  /* VAR_CLIENT_SUBNET_ZONE  */
-    VAR_CLIENT_SUBNET_ALWAYS_FORWARD = 471, /* VAR_CLIENT_SUBNET_ALWAYS_FORWARD  */
-    VAR_CLIENT_SUBNET_OPCODE = 472, /* VAR_CLIENT_SUBNET_OPCODE  */
-    VAR_MAX_CLIENT_SUBNET_IPV4 = 473, /* VAR_MAX_CLIENT_SUBNET_IPV4  */
-    VAR_MAX_CLIENT_SUBNET_IPV6 = 474, /* VAR_MAX_CLIENT_SUBNET_IPV6  */
-    VAR_MIN_CLIENT_SUBNET_IPV4 = 475, /* VAR_MIN_CLIENT_SUBNET_IPV4  */
-    VAR_MIN_CLIENT_SUBNET_IPV6 = 476, /* VAR_MIN_CLIENT_SUBNET_IPV6  */
-    VAR_MAX_ECS_TREE_SIZE_IPV4 = 477, /* VAR_MAX_ECS_TREE_SIZE_IPV4  */
-    VAR_MAX_ECS_TREE_SIZE_IPV6 = 478, /* VAR_MAX_ECS_TREE_SIZE_IPV6  */
-    VAR_CAPS_WHITELIST = 479,      /* VAR_CAPS_WHITELIST  */
-    VAR_CACHE_MAX_NEGATIVE_TTL = 480, /* VAR_CACHE_MAX_NEGATIVE_TTL  */
-    VAR_PERMIT_SMALL_HOLDDOWN = 481, /* VAR_PERMIT_SMALL_HOLDDOWN  */
-    VAR_CACHE_MIN_NEGATIVE_TTL = 482, /* VAR_CACHE_MIN_NEGATIVE_TTL  */
-    VAR_QNAME_MINIMISATION = 483,  /* VAR_QNAME_MINIMISATION  */
-    VAR_QNAME_MINIMISATION_STRICT = 484, /* VAR_QNAME_MINIMISATION_STRICT  */
-    VAR_IP_FREEBIND = 485,         /* VAR_IP_FREEBIND  */
-    VAR_DEFINE_TAG = 486,          /* VAR_DEFINE_TAG  */
-    VAR_LOCAL_ZONE_TAG = 487,      /* VAR_LOCAL_ZONE_TAG  */
-    VAR_ACCESS_CONTROL_TAG = 488,  /* VAR_ACCESS_CONTROL_TAG  */
-    VAR_LOCAL_ZONE_OVERRIDE = 489, /* VAR_LOCAL_ZONE_OVERRIDE  */
-    VAR_ACCESS_CONTROL_TAG_ACTION = 490, /* VAR_ACCESS_CONTROL_TAG_ACTION  */
-    VAR_ACCESS_CONTROL_TAG_DATA = 491, /* VAR_ACCESS_CONTROL_TAG_DATA  */
-    VAR_VIEW = 492,                /* VAR_VIEW  */
-    VAR_ACCESS_CONTROL_VIEW = 493, /* VAR_ACCESS_CONTROL_VIEW  */
-    VAR_VIEW_FIRST = 494,          /* VAR_VIEW_FIRST  */
-    VAR_SERVE_EXPIRED = 495,       /* VAR_SERVE_EXPIRED  */
-    VAR_SERVE_EXPIRED_TTL = 496,   /* VAR_SERVE_EXPIRED_TTL  */
-    VAR_SERVE_EXPIRED_TTL_RESET = 497, /* VAR_SERVE_EXPIRED_TTL_RESET  */
-    VAR_SERVE_EXPIRED_REPLY_TTL = 498, /* VAR_SERVE_EXPIRED_REPLY_TTL  */
-    VAR_SERVE_EXPIRED_CLIENT_TIMEOUT = 499, /* VAR_SERVE_EXPIRED_CLIENT_TIMEOUT  */
-    VAR_EDE_SERVE_EXPIRED = 500,   /* VAR_EDE_SERVE_EXPIRED  */
-    VAR_SERVE_ORIGINAL_TTL = 501,  /* VAR_SERVE_ORIGINAL_TTL  */
-    VAR_FAKE_DSA = 502,            /* VAR_FAKE_DSA  */
-    VAR_FAKE_SHA1 = 503,           /* VAR_FAKE_SHA1  */
-    VAR_LOG_IDENTITY = 504,        /* VAR_LOG_IDENTITY  */
-    VAR_HIDE_TRUSTANCHOR = 505,    /* VAR_HIDE_TRUSTANCHOR  */
-    VAR_HIDE_HTTP_USER_AGENT = 506, /* VAR_HIDE_HTTP_USER_AGENT  */
-    VAR_HTTP_USER_AGENT = 507,     /* VAR_HTTP_USER_AGENT  */
-    VAR_TRUST_ANCHOR_SIGNALING = 508, /* VAR_TRUST_ANCHOR_SIGNALING  */
-    VAR_AGGRESSIVE_NSEC = 509,     /* VAR_AGGRESSIVE_NSEC  */
-    VAR_USE_SYSTEMD = 510,         /* VAR_USE_SYSTEMD  */
-    VAR_SHM_ENABLE = 511,          /* VAR_SHM_ENABLE  */
-    VAR_SHM_KEY = 512,             /* VAR_SHM_KEY  */
-    VAR_ROOT_KEY_SENTINEL = 513,   /* VAR_ROOT_KEY_SENTINEL  */
-    VAR_DNSCRYPT = 514,            /* VAR_DNSCRYPT  */
-    VAR_DNSCRYPT_ENABLE = 515,     /* VAR_DNSCRYPT_ENABLE  */
-    VAR_DNSCRYPT_PORT = 516,       /* VAR_DNSCRYPT_PORT  */
-    VAR_DNSCRYPT_PROVIDER = 517,   /* VAR_DNSCRYPT_PROVIDER  */
-    VAR_DNSCRYPT_SECRET_KEY = 518, /* VAR_DNSCRYPT_SECRET_KEY  */
-    VAR_DNSCRYPT_PROVIDER_CERT = 519, /* VAR_DNSCRYPT_PROVIDER_CERT  */
-    VAR_DNSCRYPT_PROVIDER_CERT_ROTATED = 520, /* VAR_DNSCRYPT_PROVIDER_CERT_ROTATED  */
-    VAR_DNSCRYPT_SHARED_SECRET_CACHE_SIZE = 521, /* VAR_DNSCRYPT_SHARED_SECRET_CACHE_SIZE  */
-    VAR_DNSCRYPT_SHARED_SECRET_CACHE_SLABS = 522, /* VAR_DNSCRYPT_SHARED_SECRET_CACHE_SLABS  */
-    VAR_DNSCRYPT_NONCE_CACHE_SIZE = 523, /* VAR_DNSCRYPT_NONCE_CACHE_SIZE  */
-    VAR_DNSCRYPT_NONCE_CACHE_SLABS = 524, /* VAR_DNSCRYPT_NONCE_CACHE_SLABS  */
-    VAR_PAD_RESPONSES = 525,       /* VAR_PAD_RESPONSES  */
-    VAR_PAD_RESPONSES_BLOCK_SIZE = 526, /* VAR_PAD_RESPONSES_BLOCK_SIZE  */
-    VAR_PAD_QUERIES = 527,         /* VAR_PAD_QUERIES  */
-    VAR_PAD_QUERIES_BLOCK_SIZE = 528, /* VAR_PAD_QUERIES_BLOCK_SIZE  */
-    VAR_IPSECMOD_ENABLED = 529,    /* VAR_IPSECMOD_ENABLED  */
-    VAR_IPSECMOD_HOOK = 530,       /* VAR_IPSECMOD_HOOK  */
-    VAR_IPSECMOD_IGNORE_BOGUS = 531, /* VAR_IPSECMOD_IGNORE_BOGUS  */
-    VAR_IPSECMOD_MAX_TTL = 532,    /* VAR_IPSECMOD_MAX_TTL  */
-    VAR_IPSECMOD_WHITELIST = 533,  /* VAR_IPSECMOD_WHITELIST  */
-    VAR_IPSECMOD_STRICT = 534,     /* VAR_IPSECMOD_STRICT  */
-    VAR_CACHEDB = 535,             /* VAR_CACHEDB  */
-    VAR_CACHEDB_BACKEND = 536,     /* VAR_CACHEDB_BACKEND  */
-    VAR_CACHEDB_SECRETSEED = 537,  /* VAR_CACHEDB_SECRETSEED  */
-    VAR_CACHEDB_REDISHOST = 538,   /* VAR_CACHEDB_REDISHOST  */
-    VAR_CACHEDB_REDISPORT = 539,   /* VAR_CACHEDB_REDISPORT  */
-    VAR_CACHEDB_REDISTIMEOUT = 540, /* VAR_CACHEDB_REDISTIMEOUT  */
-    VAR_CACHEDB_REDISEXPIRERECORDS = 541, /* VAR_CACHEDB_REDISEXPIRERECORDS  */
-    VAR_CACHEDB_REDISPATH = 542,   /* VAR_CACHEDB_REDISPATH  */
-    VAR_CACHEDB_REDISPASSWORD = 543, /* VAR_CACHEDB_REDISPASSWORD  */
-    VAR_CACHEDB_REDISLOGICALDB = 544, /* VAR_CACHEDB_REDISLOGICALDB  */
-    VAR_UDP_UPSTREAM_WITHOUT_DOWNSTREAM = 545, /* VAR_UDP_UPSTREAM_WITHOUT_DOWNSTREAM  */
-    VAR_FOR_UPSTREAM = 546,        /* VAR_FOR_UPSTREAM  */
-    VAR_AUTH_ZONE = 547,           /* VAR_AUTH_ZONE  */
-    VAR_ZONEFILE = 548,            /* VAR_ZONEFILE  */
-    VAR_MASTER = 549,              /* VAR_MASTER  */
-    VAR_URL = 550,                 /* VAR_URL  */
-    VAR_FOR_DOWNSTREAM = 551,      /* VAR_FOR_DOWNSTREAM  */
-    VAR_FALLBACK_ENABLED = 552,    /* VAR_FALLBACK_ENABLED  */
-    VAR_TLS_ADDITIONAL_PORT = 553, /* VAR_TLS_ADDITIONAL_PORT  */
-    VAR_LOW_RTT = 554,             /* VAR_LOW_RTT  */
-    VAR_LOW_RTT_PERMIL = 555,      /* VAR_LOW_RTT_PERMIL  */
-    VAR_FAST_SERVER_PERMIL = 556,  /* VAR_FAST_SERVER_PERMIL  */
-    VAR_FAST_SERVER_NUM = 557,     /* VAR_FAST_SERVER_NUM  */
-    VAR_ALLOW_NOTIFY = 558,        /* VAR_ALLOW_NOTIFY  */
-    VAR_TLS_WIN_CERT = 559,        /* VAR_TLS_WIN_CERT  */
-    VAR_TCP_CONNECTION_LIMIT = 560, /* VAR_TCP_CONNECTION_LIMIT  */
-    VAR_ANSWER_COOKIE = 561,       /* VAR_ANSWER_COOKIE  */
-    VAR_COOKIE_SECRET = 562,       /* VAR_COOKIE_SECRET  */
-    VAR_IP_RATELIMIT_COOKIE = 563, /* VAR_IP_RATELIMIT_COOKIE  */
-    VAR_FORWARD_NO_CACHE = 564,    /* VAR_FORWARD_NO_CACHE  */
-    VAR_STUB_NO_CACHE = 565,       /* VAR_STUB_NO_CACHE  */
-    VAR_LOG_SERVFAIL = 566,        /* VAR_LOG_SERVFAIL  */
-    VAR_DENY_ANY = 567,            /* VAR_DENY_ANY  */
-    VAR_UNKNOWN_SERVER_TIME_LIMIT = 568, /* VAR_UNKNOWN_SERVER_TIME_LIMIT  */
-    VAR_LOG_TAG_QUERYREPLY = 569,  /* VAR_LOG_TAG_QUERYREPLY  */
-    VAR_DISCARD_TIMEOUT = 570,     /* VAR_DISCARD_TIMEOUT  */
-    VAR_WAIT_LIMIT = 571,          /* VAR_WAIT_LIMIT  */
-    VAR_WAIT_LIMIT_COOKIE = 572,   /* VAR_WAIT_LIMIT_COOKIE  */
-    VAR_WAIT_LIMIT_NETBLOCK = 573, /* VAR_WAIT_LIMIT_NETBLOCK  */
-    VAR_WAIT_LIMIT_COOKIE_NETBLOCK = 574, /* VAR_WAIT_LIMIT_COOKIE_NETBLOCK  */
-    VAR_STREAM_WAIT_SIZE = 575,    /* VAR_STREAM_WAIT_SIZE  */
-    VAR_TLS_CIPHERS = 576,         /* VAR_TLS_CIPHERS  */
-    VAR_TLS_CIPHERSUITES = 577,    /* VAR_TLS_CIPHERSUITES  */
-    VAR_TLS_USE_SNI = 578,         /* VAR_TLS_USE_SNI  */
-    VAR_IPSET = 579,               /* VAR_IPSET  */
-    VAR_IPSET_NAME_V4 = 580,       /* VAR_IPSET_NAME_V4  */
-    VAR_IPSET_NAME_V6 = 581,       /* VAR_IPSET_NAME_V6  */
-    VAR_TLS_SESSION_TICKET_KEYS = 582, /* VAR_TLS_SESSION_TICKET_KEYS  */
-    VAR_RPZ = 583,                 /* VAR_RPZ  */
-    VAR_TAGS = 584,                /* VAR_TAGS  */
-    VAR_RPZ_ACTION_OVERRIDE = 585, /* VAR_RPZ_ACTION_OVERRIDE  */
-    VAR_RPZ_CNAME_OVERRIDE = 586,  /* VAR_RPZ_CNAME_OVERRIDE  */
-    VAR_RPZ_LOG = 587,             /* VAR_RPZ_LOG  */
-    VAR_RPZ_LOG_NAME = 588,        /* VAR_RPZ_LOG_NAME  */
-    VAR_DYNLIB = 589,              /* VAR_DYNLIB  */
-    VAR_DYNLIB_FILE = 590,         /* VAR_DYNLIB_FILE  */
-    VAR_EDNS_CLIENT_STRING = 591,  /* VAR_EDNS_CLIENT_STRING  */
-    VAR_EDNS_CLIENT_STRING_OPCODE = 592, /* VAR_EDNS_CLIENT_STRING_OPCODE  */
-    VAR_NSID = 593,                /* VAR_NSID  */
-    VAR_ZONEMD_PERMISSIVE_MODE = 594, /* VAR_ZONEMD_PERMISSIVE_MODE  */
-    VAR_ZONEMD_CHECK = 595,        /* VAR_ZONEMD_CHECK  */
-    VAR_ZONEMD_REJECT_ABSENCE = 596, /* VAR_ZONEMD_REJECT_ABSENCE  */
-    VAR_RPZ_SIGNAL_NXDOMAIN_RA = 597, /* VAR_RPZ_SIGNAL_NXDOMAIN_RA  */
-    VAR_INTERFACE_AUTOMATIC_PORTS = 598, /* VAR_INTERFACE_AUTOMATIC_PORTS  */
-    VAR_EDE = 599,                 /* VAR_EDE  */
-    VAR_INTERFACE_ACTION = 600,    /* VAR_INTERFACE_ACTION  */
-    VAR_INTERFACE_VIEW = 601,      /* VAR_INTERFACE_VIEW  */
-    VAR_INTERFACE_TAG = 602,       /* VAR_INTERFACE_TAG  */
-    VAR_INTERFACE_TAG_ACTION = 603, /* VAR_INTERFACE_TAG_ACTION  */
-    VAR_INTERFACE_TAG_DATA = 604,  /* VAR_INTERFACE_TAG_DATA  */
-    VAR_PROXY_PROTOCOL_PORT = 605, /* VAR_PROXY_PROTOCOL_PORT  */
-    VAR_STATISTICS_INHIBIT_ZERO = 606, /* VAR_STATISTICS_INHIBIT_ZERO  */
-    VAR_HARDEN_UNKNOWN_ADDITIONAL = 607, /* VAR_HARDEN_UNKNOWN_ADDITIONAL  */
-    VAR_DISABLE_EDNS_DO = 608,     /* VAR_DISABLE_EDNS_DO  */
-    VAR_CACHEDB_NO_STORE = 609,    /* VAR_CACHEDB_NO_STORE  */
-    VAR_LOG_DESTADDR = 610,        /* VAR_LOG_DESTADDR  */
-    VAR_CACHEDB_CHECK_WHEN_SERVE_EXPIRED = 611 /* VAR_CACHEDB_CHECK_WHEN_SERVE_EXPIRED  */
+    VAR_DNSTAP_SAMPLE_RATE = 447,  /* VAR_DNSTAP_SAMPLE_RATE  */
+    VAR_RESPONSE_IP_TAG = 448,     /* VAR_RESPONSE_IP_TAG  */
+    VAR_RESPONSE_IP = 449,         /* VAR_RESPONSE_IP  */
+    VAR_RESPONSE_IP_DATA = 450,    /* VAR_RESPONSE_IP_DATA  */
+    VAR_HARDEN_ALGO_DOWNGRADE = 451, /* VAR_HARDEN_ALGO_DOWNGRADE  */
+    VAR_IP_TRANSPARENT = 452,      /* VAR_IP_TRANSPARENT  */
+    VAR_IP_DSCP = 453,             /* VAR_IP_DSCP  */
+    VAR_DISABLE_DNSSEC_LAME_CHECK = 454, /* VAR_DISABLE_DNSSEC_LAME_CHECK  */
+    VAR_IP_RATELIMIT = 455,        /* VAR_IP_RATELIMIT  */
+    VAR_IP_RATELIMIT_SLABS = 456,  /* VAR_IP_RATELIMIT_SLABS  */
+    VAR_IP_RATELIMIT_SIZE = 457,   /* VAR_IP_RATELIMIT_SIZE  */
+    VAR_RATELIMIT = 458,           /* VAR_RATELIMIT  */
+    VAR_RATELIMIT_SLABS = 459,     /* VAR_RATELIMIT_SLABS  */
+    VAR_RATELIMIT_SIZE = 460,      /* VAR_RATELIMIT_SIZE  */
+    VAR_OUTBOUND_MSG_RETRY = 461,  /* VAR_OUTBOUND_MSG_RETRY  */
+    VAR_MAX_SENT_COUNT = 462,      /* VAR_MAX_SENT_COUNT  */
+    VAR_MAX_QUERY_RESTARTS = 463,  /* VAR_MAX_QUERY_RESTARTS  */
+    VAR_RATELIMIT_FOR_DOMAIN = 464, /* VAR_RATELIMIT_FOR_DOMAIN  */
+    VAR_RATELIMIT_BELOW_DOMAIN = 465, /* VAR_RATELIMIT_BELOW_DOMAIN  */
+    VAR_IP_RATELIMIT_FACTOR = 466, /* VAR_IP_RATELIMIT_FACTOR  */
+    VAR_RATELIMIT_FACTOR = 467,    /* VAR_RATELIMIT_FACTOR  */
+    VAR_IP_RATELIMIT_BACKOFF = 468, /* VAR_IP_RATELIMIT_BACKOFF  */
+    VAR_RATELIMIT_BACKOFF = 469,   /* VAR_RATELIMIT_BACKOFF  */
+    VAR_SEND_CLIENT_SUBNET = 470,  /* VAR_SEND_CLIENT_SUBNET  */
+    VAR_CLIENT_SUBNET_ZONE = 471,  /* VAR_CLIENT_SUBNET_ZONE  */
+    VAR_CLIENT_SUBNET_ALWAYS_FORWARD = 472, /* VAR_CLIENT_SUBNET_ALWAYS_FORWARD  */
+    VAR_CLIENT_SUBNET_OPCODE = 473, /* VAR_CLIENT_SUBNET_OPCODE  */
+    VAR_MAX_CLIENT_SUBNET_IPV4 = 474, /* VAR_MAX_CLIENT_SUBNET_IPV4  */
+    VAR_MAX_CLIENT_SUBNET_IPV6 = 475, /* VAR_MAX_CLIENT_SUBNET_IPV6  */
+    VAR_MIN_CLIENT_SUBNET_IPV4 = 476, /* VAR_MIN_CLIENT_SUBNET_IPV4  */
+    VAR_MIN_CLIENT_SUBNET_IPV6 = 477, /* VAR_MIN_CLIENT_SUBNET_IPV6  */
+    VAR_MAX_ECS_TREE_SIZE_IPV4 = 478, /* VAR_MAX_ECS_TREE_SIZE_IPV4  */
+    VAR_MAX_ECS_TREE_SIZE_IPV6 = 479, /* VAR_MAX_ECS_TREE_SIZE_IPV6  */
+    VAR_CAPS_WHITELIST = 480,      /* VAR_CAPS_WHITELIST  */
+    VAR_CACHE_MAX_NEGATIVE_TTL = 481, /* VAR_CACHE_MAX_NEGATIVE_TTL  */
+    VAR_PERMIT_SMALL_HOLDDOWN = 482, /* VAR_PERMIT_SMALL_HOLDDOWN  */
+    VAR_CACHE_MIN_NEGATIVE_TTL = 483, /* VAR_CACHE_MIN_NEGATIVE_TTL  */
+    VAR_QNAME_MINIMISATION = 484,  /* VAR_QNAME_MINIMISATION  */
+    VAR_QNAME_MINIMISATION_STRICT = 485, /* VAR_QNAME_MINIMISATION_STRICT  */
+    VAR_IP_FREEBIND = 486,         /* VAR_IP_FREEBIND  */
+    VAR_DEFINE_TAG = 487,          /* VAR_DEFINE_TAG  */
+    VAR_LOCAL_ZONE_TAG = 488,      /* VAR_LOCAL_ZONE_TAG  */
+    VAR_ACCESS_CONTROL_TAG = 489,  /* VAR_ACCESS_CONTROL_TAG  */
+    VAR_LOCAL_ZONE_OVERRIDE = 490, /* VAR_LOCAL_ZONE_OVERRIDE  */
+    VAR_ACCESS_CONTROL_TAG_ACTION = 491, /* VAR_ACCESS_CONTROL_TAG_ACTION  */
+    VAR_ACCESS_CONTROL_TAG_DATA = 492, /* VAR_ACCESS_CONTROL_TAG_DATA  */
+    VAR_VIEW = 493,                /* VAR_VIEW  */
+    VAR_ACCESS_CONTROL_VIEW = 494, /* VAR_ACCESS_CONTROL_VIEW  */
+    VAR_VIEW_FIRST = 495,          /* VAR_VIEW_FIRST  */
+    VAR_SERVE_EXPIRED = 496,       /* VAR_SERVE_EXPIRED  */
+    VAR_SERVE_EXPIRED_TTL = 497,   /* VAR_SERVE_EXPIRED_TTL  */
+    VAR_SERVE_EXPIRED_TTL_RESET = 498, /* VAR_SERVE_EXPIRED_TTL_RESET  */
+    VAR_SERVE_EXPIRED_REPLY_TTL = 499, /* VAR_SERVE_EXPIRED_REPLY_TTL  */
+    VAR_SERVE_EXPIRED_CLIENT_TIMEOUT = 500, /* VAR_SERVE_EXPIRED_CLIENT_TIMEOUT  */
+    VAR_EDE_SERVE_EXPIRED = 501,   /* VAR_EDE_SERVE_EXPIRED  */
+    VAR_SERVE_ORIGINAL_TTL = 502,  /* VAR_SERVE_ORIGINAL_TTL  */
+    VAR_FAKE_DSA = 503,            /* VAR_FAKE_DSA  */
+    VAR_FAKE_SHA1 = 504,           /* VAR_FAKE_SHA1  */
+    VAR_LOG_IDENTITY = 505,        /* VAR_LOG_IDENTITY  */
+    VAR_HIDE_TRUSTANCHOR = 506,    /* VAR_HIDE_TRUSTANCHOR  */
+    VAR_HIDE_HTTP_USER_AGENT = 507, /* VAR_HIDE_HTTP_USER_AGENT  */
+    VAR_HTTP_USER_AGENT = 508,     /* VAR_HTTP_USER_AGENT  */
+    VAR_TRUST_ANCHOR_SIGNALING = 509, /* VAR_TRUST_ANCHOR_SIGNALING  */
+    VAR_AGGRESSIVE_NSEC = 510,     /* VAR_AGGRESSIVE_NSEC  */
+    VAR_USE_SYSTEMD = 511,         /* VAR_USE_SYSTEMD  */
+    VAR_SHM_ENABLE = 512,          /* VAR_SHM_ENABLE  */
+    VAR_SHM_KEY = 513,             /* VAR_SHM_KEY  */
+    VAR_ROOT_KEY_SENTINEL = 514,   /* VAR_ROOT_KEY_SENTINEL  */
+    VAR_DNSCRYPT = 515,            /* VAR_DNSCRYPT  */
+    VAR_DNSCRYPT_ENABLE = 516,     /* VAR_DNSCRYPT_ENABLE  */
+    VAR_DNSCRYPT_PORT = 517,       /* VAR_DNSCRYPT_PORT  */
+    VAR_DNSCRYPT_PROVIDER = 518,   /* VAR_DNSCRYPT_PROVIDER  */
+    VAR_DNSCRYPT_SECRET_KEY = 519, /* VAR_DNSCRYPT_SECRET_KEY  */
+    VAR_DNSCRYPT_PROVIDER_CERT = 520, /* VAR_DNSCRYPT_PROVIDER_CERT  */
+    VAR_DNSCRYPT_PROVIDER_CERT_ROTATED = 521, /* VAR_DNSCRYPT_PROVIDER_CERT_ROTATED  */
+    VAR_DNSCRYPT_SHARED_SECRET_CACHE_SIZE = 522, /* VAR_DNSCRYPT_SHARED_SECRET_CACHE_SIZE  */
+    VAR_DNSCRYPT_SHARED_SECRET_CACHE_SLABS = 523, /* VAR_DNSCRYPT_SHARED_SECRET_CACHE_SLABS  */
+    VAR_DNSCRYPT_NONCE_CACHE_SIZE = 524, /* VAR_DNSCRYPT_NONCE_CACHE_SIZE  */
+    VAR_DNSCRYPT_NONCE_CACHE_SLABS = 525, /* VAR_DNSCRYPT_NONCE_CACHE_SLABS  */
+    VAR_PAD_RESPONSES = 526,       /* VAR_PAD_RESPONSES  */
+    VAR_PAD_RESPONSES_BLOCK_SIZE = 527, /* VAR_PAD_RESPONSES_BLOCK_SIZE  */
+    VAR_PAD_QUERIES = 528,         /* VAR_PAD_QUERIES  */
+    VAR_PAD_QUERIES_BLOCK_SIZE = 529, /* VAR_PAD_QUERIES_BLOCK_SIZE  */
+    VAR_IPSECMOD_ENABLED = 530,    /* VAR_IPSECMOD_ENABLED  */
+    VAR_IPSECMOD_HOOK = 531,       /* VAR_IPSECMOD_HOOK  */
+    VAR_IPSECMOD_IGNORE_BOGUS = 532, /* VAR_IPSECMOD_IGNORE_BOGUS  */
+    VAR_IPSECMOD_MAX_TTL = 533,    /* VAR_IPSECMOD_MAX_TTL  */
+    VAR_IPSECMOD_WHITELIST = 534,  /* VAR_IPSECMOD_WHITELIST  */
+    VAR_IPSECMOD_STRICT = 535,     /* VAR_IPSECMOD_STRICT  */
+    VAR_CACHEDB = 536,             /* VAR_CACHEDB  */
+    VAR_CACHEDB_BACKEND = 537,     /* VAR_CACHEDB_BACKEND  */
+    VAR_CACHEDB_SECRETSEED = 538,  /* VAR_CACHEDB_SECRETSEED  */
+    VAR_CACHEDB_REDISHOST = 539,   /* VAR_CACHEDB_REDISHOST  */
+    VAR_CACHEDB_REDISREPLICAHOST = 540, /* VAR_CACHEDB_REDISREPLICAHOST  */
+    VAR_CACHEDB_REDISPORT = 541,   /* VAR_CACHEDB_REDISPORT  */
+    VAR_CACHEDB_REDISREPLICAPORT = 542, /* VAR_CACHEDB_REDISREPLICAPORT  */
+    VAR_CACHEDB_REDISTIMEOUT = 543, /* VAR_CACHEDB_REDISTIMEOUT  */
+    VAR_CACHEDB_REDISREPLICATIMEOUT = 544, /* VAR_CACHEDB_REDISREPLICATIMEOUT  */
+    VAR_CACHEDB_REDISEXPIRERECORDS = 545, /* VAR_CACHEDB_REDISEXPIRERECORDS  */
+    VAR_CACHEDB_REDISPATH = 546,   /* VAR_CACHEDB_REDISPATH  */
+    VAR_CACHEDB_REDISREPLICAPATH = 547, /* VAR_CACHEDB_REDISREPLICAPATH  */
+    VAR_CACHEDB_REDISPASSWORD = 548, /* VAR_CACHEDB_REDISPASSWORD  */
+    VAR_CACHEDB_REDISREPLICAPASSWORD = 549, /* VAR_CACHEDB_REDISREPLICAPASSWORD  */
+    VAR_CACHEDB_REDISLOGICALDB = 550, /* VAR_CACHEDB_REDISLOGICALDB  */
+    VAR_CACHEDB_REDISREPLICALOGICALDB = 551, /* VAR_CACHEDB_REDISREPLICALOGICALDB  */
+    VAR_CACHEDB_REDISCOMMANDTIMEOUT = 552, /* VAR_CACHEDB_REDISCOMMANDTIMEOUT  */
+    VAR_CACHEDB_REDISREPLICACOMMANDTIMEOUT = 553, /* VAR_CACHEDB_REDISREPLICACOMMANDTIMEOUT  */
+    VAR_CACHEDB_REDISCONNECTTIMEOUT = 554, /* VAR_CACHEDB_REDISCONNECTTIMEOUT  */
+    VAR_CACHEDB_REDISREPLICACONNECTTIMEOUT = 555, /* VAR_CACHEDB_REDISREPLICACONNECTTIMEOUT  */
+    VAR_UDP_UPSTREAM_WITHOUT_DOWNSTREAM = 556, /* VAR_UDP_UPSTREAM_WITHOUT_DOWNSTREAM  */
+    VAR_FOR_UPSTREAM = 557,        /* VAR_FOR_UPSTREAM  */
+    VAR_AUTH_ZONE = 558,           /* VAR_AUTH_ZONE  */
+    VAR_ZONEFILE = 559,            /* VAR_ZONEFILE  */
+    VAR_MASTER = 560,              /* VAR_MASTER  */
+    VAR_URL = 561,                 /* VAR_URL  */
+    VAR_FOR_DOWNSTREAM = 562,      /* VAR_FOR_DOWNSTREAM  */
+    VAR_FALLBACK_ENABLED = 563,    /* VAR_FALLBACK_ENABLED  */
+    VAR_TLS_ADDITIONAL_PORT = 564, /* VAR_TLS_ADDITIONAL_PORT  */
+    VAR_LOW_RTT = 565,             /* VAR_LOW_RTT  */
+    VAR_LOW_RTT_PERMIL = 566,      /* VAR_LOW_RTT_PERMIL  */
+    VAR_FAST_SERVER_PERMIL = 567,  /* VAR_FAST_SERVER_PERMIL  */
+    VAR_FAST_SERVER_NUM = 568,     /* VAR_FAST_SERVER_NUM  */
+    VAR_ALLOW_NOTIFY = 569,        /* VAR_ALLOW_NOTIFY  */
+    VAR_TLS_WIN_CERT = 570,        /* VAR_TLS_WIN_CERT  */
+    VAR_TCP_CONNECTION_LIMIT = 571, /* VAR_TCP_CONNECTION_LIMIT  */
+    VAR_ANSWER_COOKIE = 572,       /* VAR_ANSWER_COOKIE  */
+    VAR_COOKIE_SECRET = 573,       /* VAR_COOKIE_SECRET  */
+    VAR_IP_RATELIMIT_COOKIE = 574, /* VAR_IP_RATELIMIT_COOKIE  */
+    VAR_FORWARD_NO_CACHE = 575,    /* VAR_FORWARD_NO_CACHE  */
+    VAR_STUB_NO_CACHE = 576,       /* VAR_STUB_NO_CACHE  */
+    VAR_LOG_SERVFAIL = 577,        /* VAR_LOG_SERVFAIL  */
+    VAR_DENY_ANY = 578,            /* VAR_DENY_ANY  */
+    VAR_UNKNOWN_SERVER_TIME_LIMIT = 579, /* VAR_UNKNOWN_SERVER_TIME_LIMIT  */
+    VAR_LOG_TAG_QUERYREPLY = 580,  /* VAR_LOG_TAG_QUERYREPLY  */
+    VAR_DISCARD_TIMEOUT = 581,     /* VAR_DISCARD_TIMEOUT  */
+    VAR_WAIT_LIMIT = 582,          /* VAR_WAIT_LIMIT  */
+    VAR_WAIT_LIMIT_COOKIE = 583,   /* VAR_WAIT_LIMIT_COOKIE  */
+    VAR_WAIT_LIMIT_NETBLOCK = 584, /* VAR_WAIT_LIMIT_NETBLOCK  */
+    VAR_WAIT_LIMIT_COOKIE_NETBLOCK = 585, /* VAR_WAIT_LIMIT_COOKIE_NETBLOCK  */
+    VAR_STREAM_WAIT_SIZE = 586,    /* VAR_STREAM_WAIT_SIZE  */
+    VAR_TLS_CIPHERS = 587,         /* VAR_TLS_CIPHERS  */
+    VAR_TLS_CIPHERSUITES = 588,    /* VAR_TLS_CIPHERSUITES  */
+    VAR_TLS_USE_SNI = 589,         /* VAR_TLS_USE_SNI  */
+    VAR_IPSET = 590,               /* VAR_IPSET  */
+    VAR_IPSET_NAME_V4 = 591,       /* VAR_IPSET_NAME_V4  */
+    VAR_IPSET_NAME_V6 = 592,       /* VAR_IPSET_NAME_V6  */
+    VAR_TLS_SESSION_TICKET_KEYS = 593, /* VAR_TLS_SESSION_TICKET_KEYS  */
+    VAR_RPZ = 594,                 /* VAR_RPZ  */
+    VAR_TAGS = 595,                /* VAR_TAGS  */
+    VAR_RPZ_ACTION_OVERRIDE = 596, /* VAR_RPZ_ACTION_OVERRIDE  */
+    VAR_RPZ_CNAME_OVERRIDE = 597,  /* VAR_RPZ_CNAME_OVERRIDE  */
+    VAR_RPZ_LOG = 598,             /* VAR_RPZ_LOG  */
+    VAR_RPZ_LOG_NAME = 599,        /* VAR_RPZ_LOG_NAME  */
+    VAR_DYNLIB = 600,              /* VAR_DYNLIB  */
+    VAR_DYNLIB_FILE = 601,         /* VAR_DYNLIB_FILE  */
+    VAR_EDNS_CLIENT_STRING = 602,  /* VAR_EDNS_CLIENT_STRING  */
+    VAR_EDNS_CLIENT_STRING_OPCODE = 603, /* VAR_EDNS_CLIENT_STRING_OPCODE  */
+    VAR_NSID = 604,                /* VAR_NSID  */
+    VAR_ZONEMD_PERMISSIVE_MODE = 605, /* VAR_ZONEMD_PERMISSIVE_MODE  */
+    VAR_ZONEMD_CHECK = 606,        /* VAR_ZONEMD_CHECK  */
+    VAR_ZONEMD_REJECT_ABSENCE = 607, /* VAR_ZONEMD_REJECT_ABSENCE  */
+    VAR_RPZ_SIGNAL_NXDOMAIN_RA = 608, /* VAR_RPZ_SIGNAL_NXDOMAIN_RA  */
+    VAR_INTERFACE_AUTOMATIC_PORTS = 609, /* VAR_INTERFACE_AUTOMATIC_PORTS  */
+    VAR_EDE = 610,                 /* VAR_EDE  */
+    VAR_DNS_ERROR_REPORTING = 611, /* VAR_DNS_ERROR_REPORTING  */
+    VAR_INTERFACE_ACTION = 612,    /* VAR_INTERFACE_ACTION  */
+    VAR_INTERFACE_VIEW = 613,      /* VAR_INTERFACE_VIEW  */
+    VAR_INTERFACE_TAG = 614,       /* VAR_INTERFACE_TAG  */
+    VAR_INTERFACE_TAG_ACTION = 615, /* VAR_INTERFACE_TAG_ACTION  */
+    VAR_INTERFACE_TAG_DATA = 616,  /* VAR_INTERFACE_TAG_DATA  */
+    VAR_QUIC_PORT = 617,           /* VAR_QUIC_PORT  */
+    VAR_QUIC_SIZE = 618,           /* VAR_QUIC_SIZE  */
+    VAR_PROXY_PROTOCOL_PORT = 619, /* VAR_PROXY_PROTOCOL_PORT  */
+    VAR_STATISTICS_INHIBIT_ZERO = 620, /* VAR_STATISTICS_INHIBIT_ZERO  */
+    VAR_HARDEN_UNKNOWN_ADDITIONAL = 621, /* VAR_HARDEN_UNKNOWN_ADDITIONAL  */
+    VAR_DISABLE_EDNS_DO = 622,     /* VAR_DISABLE_EDNS_DO  */
+    VAR_CACHEDB_NO_STORE = 623,    /* VAR_CACHEDB_NO_STORE  */
+    VAR_LOG_DESTADDR = 624,        /* VAR_LOG_DESTADDR  */
+    VAR_CACHEDB_CHECK_WHEN_SERVE_EXPIRED = 625, /* VAR_CACHEDB_CHECK_WHEN_SERVE_EXPIRED  */
+    VAR_COOKIE_SECRET_FILE = 626,  /* VAR_COOKIE_SECRET_FILE  */
+    VAR_ITER_SCRUB_NS = 627,       /* VAR_ITER_SCRUB_NS  */
+    VAR_ITER_SCRUB_CNAME = 628,    /* VAR_ITER_SCRUB_CNAME  */
+    VAR_MAX_GLOBAL_QUOTA = 629,    /* VAR_MAX_GLOBAL_QUOTA  */
+    VAR_HARDEN_UNVERIFIED_GLUE = 630, /* VAR_HARDEN_UNVERIFIED_GLUE  */
+    VAR_LOG_TIME_ISO = 631         /* VAR_LOG_TIME_ISO  */
   };
   typedef enum yytokentype yytoken_kind_t;
 #endif
@@ -605,171 +625,191 @@ extern int yydebug;
 #define VAR_DNSTAP_LOG_CLIENT_RESPONSE_MESSAGES 444
 #define VAR_DNSTAP_LOG_FORWARDER_QUERY_MESSAGES 445
 #define VAR_DNSTAP_LOG_FORWARDER_RESPONSE_MESSAGES 446
-#define VAR_RESPONSE_IP_TAG 447
-#define VAR_RESPONSE_IP 448
-#define VAR_RESPONSE_IP_DATA 449
-#define VAR_HARDEN_ALGO_DOWNGRADE 450
-#define VAR_IP_TRANSPARENT 451
-#define VAR_IP_DSCP 452
-#define VAR_DISABLE_DNSSEC_LAME_CHECK 453
-#define VAR_IP_RATELIMIT 454
-#define VAR_IP_RATELIMIT_SLABS 455
-#define VAR_IP_RATELIMIT_SIZE 456
-#define VAR_RATELIMIT 457
-#define VAR_RATELIMIT_SLABS 458
-#define VAR_RATELIMIT_SIZE 459
-#define VAR_OUTBOUND_MSG_RETRY 460
-#define VAR_MAX_SENT_COUNT 461
-#define VAR_MAX_QUERY_RESTARTS 462
-#define VAR_RATELIMIT_FOR_DOMAIN 463
-#define VAR_RATELIMIT_BELOW_DOMAIN 464
-#define VAR_IP_RATELIMIT_FACTOR 465
-#define VAR_RATELIMIT_FACTOR 466
-#define VAR_IP_RATELIMIT_BACKOFF 467
-#define VAR_RATELIMIT_BACKOFF 468
-#define VAR_SEND_CLIENT_SUBNET 469
-#define VAR_CLIENT_SUBNET_ZONE 470
-#define VAR_CLIENT_SUBNET_ALWAYS_FORWARD 471
-#define VAR_CLIENT_SUBNET_OPCODE 472
-#define VAR_MAX_CLIENT_SUBNET_IPV4 473
-#define VAR_MAX_CLIENT_SUBNET_IPV6 474
-#define VAR_MIN_CLIENT_SUBNET_IPV4 475
-#define VAR_MIN_CLIENT_SUBNET_IPV6 476
-#define VAR_MAX_ECS_TREE_SIZE_IPV4 477
-#define VAR_MAX_ECS_TREE_SIZE_IPV6 478
-#define VAR_CAPS_WHITELIST 479
-#define VAR_CACHE_MAX_NEGATIVE_TTL 480
-#define VAR_PERMIT_SMALL_HOLDDOWN 481
-#define VAR_CACHE_MIN_NEGATIVE_TTL 482
-#define VAR_QNAME_MINIMISATION 483
-#define VAR_QNAME_MINIMISATION_STRICT 484
-#define VAR_IP_FREEBIND 485
-#define VAR_DEFINE_TAG 486
-#define VAR_LOCAL_ZONE_TAG 487
-#define VAR_ACCESS_CONTROL_TAG 488
-#define VAR_LOCAL_ZONE_OVERRIDE 489
-#define VAR_ACCESS_CONTROL_TAG_ACTION 490
-#define VAR_ACCESS_CONTROL_TAG_DATA 491
-#define VAR_VIEW 492
-#define VAR_ACCESS_CONTROL_VIEW 493
-#define VAR_VIEW_FIRST 494
-#define VAR_SERVE_EXPIRED 495
-#define VAR_SERVE_EXPIRED_TTL 496
-#define VAR_SERVE_EXPIRED_TTL_RESET 497
-#define VAR_SERVE_EXPIRED_REPLY_TTL 498
-#define VAR_SERVE_EXPIRED_CLIENT_TIMEOUT 499
-#define VAR_EDE_SERVE_EXPIRED 500
-#define VAR_SERVE_ORIGINAL_TTL 501
-#define VAR_FAKE_DSA 502
-#define VAR_FAKE_SHA1 503
-#define VAR_LOG_IDENTITY 504
-#define VAR_HIDE_TRUSTANCHOR 505
-#define VAR_HIDE_HTTP_USER_AGENT 506
-#define VAR_HTTP_USER_AGENT 507
-#define VAR_TRUST_ANCHOR_SIGNALING 508
-#define VAR_AGGRESSIVE_NSEC 509
-#define VAR_USE_SYSTEMD 510
-#define VAR_SHM_ENABLE 511
-#define VAR_SHM_KEY 512
-#define VAR_ROOT_KEY_SENTINEL 513
-#define VAR_DNSCRYPT 514
-#define VAR_DNSCRYPT_ENABLE 515
-#define VAR_DNSCRYPT_PORT 516
-#define VAR_DNSCRYPT_PROVIDER 517
-#define VAR_DNSCRYPT_SECRET_KEY 518
-#define VAR_DNSCRYPT_PROVIDER_CERT 519
-#define VAR_DNSCRYPT_PROVIDER_CERT_ROTATED 520
-#define VAR_DNSCRYPT_SHARED_SECRET_CACHE_SIZE 521
-#define VAR_DNSCRYPT_SHARED_SECRET_CACHE_SLABS 522
-#define VAR_DNSCRYPT_NONCE_CACHE_SIZE 523
-#define VAR_DNSCRYPT_NONCE_CACHE_SLABS 524
-#define VAR_PAD_RESPONSES 525
-#define VAR_PAD_RESPONSES_BLOCK_SIZE 526
-#define VAR_PAD_QUERIES 527
-#define VAR_PAD_QUERIES_BLOCK_SIZE 528
-#define VAR_IPSECMOD_ENABLED 529
-#define VAR_IPSECMOD_HOOK 530
-#define VAR_IPSECMOD_IGNORE_BOGUS 531
-#define VAR_IPSECMOD_MAX_TTL 532
-#define VAR_IPSECMOD_WHITELIST 533
-#define VAR_IPSECMOD_STRICT 534
-#define VAR_CACHEDB 535
-#define VAR_CACHEDB_BACKEND 536
-#define VAR_CACHEDB_SECRETSEED 537
-#define VAR_CACHEDB_REDISHOST 538
-#define VAR_CACHEDB_REDISPORT 539
-#define VAR_CACHEDB_REDISTIMEOUT 540
-#define VAR_CACHEDB_REDISEXPIRERECORDS 541
-#define VAR_CACHEDB_REDISPATH 542
-#define VAR_CACHEDB_REDISPASSWORD 543
-#define VAR_CACHEDB_REDISLOGICALDB 544
-#define VAR_UDP_UPSTREAM_WITHOUT_DOWNSTREAM 545
-#define VAR_FOR_UPSTREAM 546
-#define VAR_AUTH_ZONE 547
-#define VAR_ZONEFILE 548
-#define VAR_MASTER 549
-#define VAR_URL 550
-#define VAR_FOR_DOWNSTREAM 551
-#define VAR_FALLBACK_ENABLED 552
-#define VAR_TLS_ADDITIONAL_PORT 553
-#define VAR_LOW_RTT 554
-#define VAR_LOW_RTT_PERMIL 555
-#define VAR_FAST_SERVER_PERMIL 556
-#define VAR_FAST_SERVER_NUM 557
-#define VAR_ALLOW_NOTIFY 558
-#define VAR_TLS_WIN_CERT 559
-#define VAR_TCP_CONNECTION_LIMIT 560
-#define VAR_ANSWER_COOKIE 561
-#define VAR_COOKIE_SECRET 562
-#define VAR_IP_RATELIMIT_COOKIE 563
-#define VAR_FORWARD_NO_CACHE 564
-#define VAR_STUB_NO_CACHE 565
-#define VAR_LOG_SERVFAIL 566
-#define VAR_DENY_ANY 567
-#define VAR_UNKNOWN_SERVER_TIME_LIMIT 568
-#define VAR_LOG_TAG_QUERYREPLY 569
-#define VAR_DISCARD_TIMEOUT 570
-#define VAR_WAIT_LIMIT 571
-#define VAR_WAIT_LIMIT_COOKIE 572
-#define VAR_WAIT_LIMIT_NETBLOCK 573
-#define VAR_WAIT_LIMIT_COOKIE_NETBLOCK 574
-#define VAR_STREAM_WAIT_SIZE 575
-#define VAR_TLS_CIPHERS 576
-#define VAR_TLS_CIPHERSUITES 577
-#define VAR_TLS_USE_SNI 578
-#define VAR_IPSET 579
-#define VAR_IPSET_NAME_V4 580
-#define VAR_IPSET_NAME_V6 581
-#define VAR_TLS_SESSION_TICKET_KEYS 582
-#define VAR_RPZ 583
-#define VAR_TAGS 584
-#define VAR_RPZ_ACTION_OVERRIDE 585
-#define VAR_RPZ_CNAME_OVERRIDE 586
-#define VAR_RPZ_LOG 587
-#define VAR_RPZ_LOG_NAME 588
-#define VAR_DYNLIB 589
-#define VAR_DYNLIB_FILE 590
-#define VAR_EDNS_CLIENT_STRING 591
-#define VAR_EDNS_CLIENT_STRING_OPCODE 592
-#define VAR_NSID 593
-#define VAR_ZONEMD_PERMISSIVE_MODE 594
-#define VAR_ZONEMD_CHECK 595
-#define VAR_ZONEMD_REJECT_ABSENCE 596
-#define VAR_RPZ_SIGNAL_NXDOMAIN_RA 597
-#define VAR_INTERFACE_AUTOMATIC_PORTS 598
-#define VAR_EDE 599
-#define VAR_INTERFACE_ACTION 600
-#define VAR_INTERFACE_VIEW 601
-#define VAR_INTERFACE_TAG 602
-#define VAR_INTERFACE_TAG_ACTION 603
-#define VAR_INTERFACE_TAG_DATA 604
-#define VAR_PROXY_PROTOCOL_PORT 605
-#define VAR_STATISTICS_INHIBIT_ZERO 606
-#define VAR_HARDEN_UNKNOWN_ADDITIONAL 607
-#define VAR_DISABLE_EDNS_DO 608
-#define VAR_CACHEDB_NO_STORE 609
-#define VAR_LOG_DESTADDR 610
-#define VAR_CACHEDB_CHECK_WHEN_SERVE_EXPIRED 611
+#define VAR_DNSTAP_SAMPLE_RATE 447
+#define VAR_RESPONSE_IP_TAG 448
+#define VAR_RESPONSE_IP 449
+#define VAR_RESPONSE_IP_DATA 450
+#define VAR_HARDEN_ALGO_DOWNGRADE 451
+#define VAR_IP_TRANSPARENT 452
+#define VAR_IP_DSCP 453
+#define VAR_DISABLE_DNSSEC_LAME_CHECK 454
+#define VAR_IP_RATELIMIT 455
+#define VAR_IP_RATELIMIT_SLABS 456
+#define VAR_IP_RATELIMIT_SIZE 457
+#define VAR_RATELIMIT 458
+#define VAR_RATELIMIT_SLABS 459
+#define VAR_RATELIMIT_SIZE 460
+#define VAR_OUTBOUND_MSG_RETRY 461
+#define VAR_MAX_SENT_COUNT 462
+#define VAR_MAX_QUERY_RESTARTS 463
+#define VAR_RATELIMIT_FOR_DOMAIN 464
+#define VAR_RATELIMIT_BELOW_DOMAIN 465
+#define VAR_IP_RATELIMIT_FACTOR 466
+#define VAR_RATELIMIT_FACTOR 467
+#define VAR_IP_RATELIMIT_BACKOFF 468
+#define VAR_RATELIMIT_BACKOFF 469
+#define VAR_SEND_CLIENT_SUBNET 470
+#define VAR_CLIENT_SUBNET_ZONE 471
+#define VAR_CLIENT_SUBNET_ALWAYS_FORWARD 472
+#define VAR_CLIENT_SUBNET_OPCODE 473
+#define VAR_MAX_CLIENT_SUBNET_IPV4 474
+#define VAR_MAX_CLIENT_SUBNET_IPV6 475
+#define VAR_MIN_CLIENT_SUBNET_IPV4 476
+#define VAR_MIN_CLIENT_SUBNET_IPV6 477
+#define VAR_MAX_ECS_TREE_SIZE_IPV4 478
+#define VAR_MAX_ECS_TREE_SIZE_IPV6 479
+#define VAR_CAPS_WHITELIST 480
+#define VAR_CACHE_MAX_NEGATIVE_TTL 481
+#define VAR_PERMIT_SMALL_HOLDDOWN 482
+#define VAR_CACHE_MIN_NEGATIVE_TTL 483
+#define VAR_QNAME_MINIMISATION 484
+#define VAR_QNAME_MINIMISATION_STRICT 485
+#define VAR_IP_FREEBIND 486
+#define VAR_DEFINE_TAG 487
+#define VAR_LOCAL_ZONE_TAG 488
+#define VAR_ACCESS_CONTROL_TAG 489
+#define VAR_LOCAL_ZONE_OVERRIDE 490
+#define VAR_ACCESS_CONTROL_TAG_ACTION 491
+#define VAR_ACCESS_CONTROL_TAG_DATA 492
+#define VAR_VIEW 493
+#define VAR_ACCESS_CONTROL_VIEW 494
+#define VAR_VIEW_FIRST 495
+#define VAR_SERVE_EXPIRED 496
+#define VAR_SERVE_EXPIRED_TTL 497
+#define VAR_SERVE_EXPIRED_TTL_RESET 498
+#define VAR_SERVE_EXPIRED_REPLY_TTL 499
+#define VAR_SERVE_EXPIRED_CLIENT_TIMEOUT 500
+#define VAR_EDE_SERVE_EXPIRED 501
+#define VAR_SERVE_ORIGINAL_TTL 502
+#define VAR_FAKE_DSA 503
+#define VAR_FAKE_SHA1 504
+#define VAR_LOG_IDENTITY 505
+#define VAR_HIDE_TRUSTANCHOR 506
+#define VAR_HIDE_HTTP_USER_AGENT 507
+#define VAR_HTTP_USER_AGENT 508
+#define VAR_TRUST_ANCHOR_SIGNALING 509
+#define VAR_AGGRESSIVE_NSEC 510
+#define VAR_USE_SYSTEMD 511
+#define VAR_SHM_ENABLE 512
+#define VAR_SHM_KEY 513
+#define VAR_ROOT_KEY_SENTINEL 514
+#define VAR_DNSCRYPT 515
+#define VAR_DNSCRYPT_ENABLE 516
+#define VAR_DNSCRYPT_PORT 517
+#define VAR_DNSCRYPT_PROVIDER 518
+#define VAR_DNSCRYPT_SECRET_KEY 519
+#define VAR_DNSCRYPT_PROVIDER_CERT 520
+#define VAR_DNSCRYPT_PROVIDER_CERT_ROTATED 521
+#define VAR_DNSCRYPT_SHARED_SECRET_CACHE_SIZE 522
+#define VAR_DNSCRYPT_SHARED_SECRET_CACHE_SLABS 523
+#define VAR_DNSCRYPT_NONCE_CACHE_SIZE 524
+#define VAR_DNSCRYPT_NONCE_CACHE_SLABS 525
+#define VAR_PAD_RESPONSES 526
+#define VAR_PAD_RESPONSES_BLOCK_SIZE 527
+#define VAR_PAD_QUERIES 528
+#define VAR_PAD_QUERIES_BLOCK_SIZE 529
+#define VAR_IPSECMOD_ENABLED 530
+#define VAR_IPSECMOD_HOOK 531
+#define VAR_IPSECMOD_IGNORE_BOGUS 532
+#define VAR_IPSECMOD_MAX_TTL 533
+#define VAR_IPSECMOD_WHITELIST 534
+#define VAR_IPSECMOD_STRICT 535
+#define VAR_CACHEDB 536
+#define VAR_CACHEDB_BACKEND 537
+#define VAR_CACHEDB_SECRETSEED 538
+#define VAR_CACHEDB_REDISHOST 539
+#define VAR_CACHEDB_REDISREPLICAHOST 540
+#define VAR_CACHEDB_REDISPORT 541
+#define VAR_CACHEDB_REDISREPLICAPORT 542
+#define VAR_CACHEDB_REDISTIMEOUT 543
+#define VAR_CACHEDB_REDISREPLICATIMEOUT 544
+#define VAR_CACHEDB_REDISEXPIRERECORDS 545
+#define VAR_CACHEDB_REDISPATH 546
+#define VAR_CACHEDB_REDISREPLICAPATH 547
+#define VAR_CACHEDB_REDISPASSWORD 548
+#define VAR_CACHEDB_REDISREPLICAPASSWORD 549
+#define VAR_CACHEDB_REDISLOGICALDB 550
+#define VAR_CACHEDB_REDISREPLICALOGICALDB 551
+#define VAR_CACHEDB_REDISCOMMANDTIMEOUT 552
+#define VAR_CACHEDB_REDISREPLICACOMMANDTIMEOUT 553
+#define VAR_CACHEDB_REDISCONNECTTIMEOUT 554
+#define VAR_CACHEDB_REDISREPLICACONNECTTIMEOUT 555
+#define VAR_UDP_UPSTREAM_WITHOUT_DOWNSTREAM 556
+#define VAR_FOR_UPSTREAM 557
+#define VAR_AUTH_ZONE 558
+#define VAR_ZONEFILE 559
+#define VAR_MASTER 560
+#define VAR_URL 561
+#define VAR_FOR_DOWNSTREAM 562
+#define VAR_FALLBACK_ENABLED 563
+#define VAR_TLS_ADDITIONAL_PORT 564
+#define VAR_LOW_RTT 565
+#define VAR_LOW_RTT_PERMIL 566
+#define VAR_FAST_SERVER_PERMIL 567
+#define VAR_FAST_SERVER_NUM 568
+#define VAR_ALLOW_NOTIFY 569
+#define VAR_TLS_WIN_CERT 570
+#define VAR_TCP_CONNECTION_LIMIT 571
+#define VAR_ANSWER_COOKIE 572
+#define VAR_COOKIE_SECRET 573
+#define VAR_IP_RATELIMIT_COOKIE 574
+#define VAR_FORWARD_NO_CACHE 575
+#define VAR_STUB_NO_CACHE 576
+#define VAR_LOG_SERVFAIL 577
+#define VAR_DENY_ANY 578
+#define VAR_UNKNOWN_SERVER_TIME_LIMIT 579
+#define VAR_LOG_TAG_QUERYREPLY 580
+#define VAR_DISCARD_TIMEOUT 581
+#define VAR_WAIT_LIMIT 582
+#define VAR_WAIT_LIMIT_COOKIE 583
+#define VAR_WAIT_LIMIT_NETBLOCK 584
+#define VAR_WAIT_LIMIT_COOKIE_NETBLOCK 585
+#define VAR_STREAM_WAIT_SIZE 586
+#define VAR_TLS_CIPHERS 587
+#define VAR_TLS_CIPHERSUITES 588
+#define VAR_TLS_USE_SNI 589
+#define VAR_IPSET 590
+#define VAR_IPSET_NAME_V4 591
+#define VAR_IPSET_NAME_V6 592
+#define VAR_TLS_SESSION_TICKET_KEYS 593
+#define VAR_RPZ 594
+#define VAR_TAGS 595
+#define VAR_RPZ_ACTION_OVERRIDE 596
+#define VAR_RPZ_CNAME_OVERRIDE 597
+#define VAR_RPZ_LOG 598
+#define VAR_RPZ_LOG_NAME 599
+#define VAR_DYNLIB 600
+#define VAR_DYNLIB_FILE 601
+#define VAR_EDNS_CLIENT_STRING 602
+#define VAR_EDNS_CLIENT_STRING_OPCODE 603
+#define VAR_NSID 604
+#define VAR_ZONEMD_PERMISSIVE_MODE 605
+#define VAR_ZONEMD_CHECK 606
+#define VAR_ZONEMD_REJECT_ABSENCE 607
+#define VAR_RPZ_SIGNAL_NXDOMAIN_RA 608
+#define VAR_INTERFACE_AUTOMATIC_PORTS 609
+#define VAR_EDE 610
+#define VAR_DNS_ERROR_REPORTING 611
+#define VAR_INTERFACE_ACTION 612
+#define VAR_INTERFACE_VIEW 613
+#define VAR_INTERFACE_TAG 614
+#define VAR_INTERFACE_TAG_ACTION 615
+#define VAR_INTERFACE_TAG_DATA 616
+#define VAR_QUIC_PORT 617
+#define VAR_QUIC_SIZE 618
+#define VAR_PROXY_PROTOCOL_PORT 619
+#define VAR_STATISTICS_INHIBIT_ZERO 620
+#define VAR_HARDEN_UNKNOWN_ADDITIONAL 621
+#define VAR_DISABLE_EDNS_DO 622
+#define VAR_CACHEDB_NO_STORE 623
+#define VAR_LOG_DESTADDR 624
+#define VAR_CACHEDB_CHECK_WHEN_SERVE_EXPIRED 625
+#define VAR_COOKIE_SECRET_FILE 626
+#define VAR_ITER_SCRUB_NS 627
+#define VAR_ITER_SCRUB_CNAME 628
+#define VAR_MAX_GLOBAL_QUOTA 629
+#define VAR_HARDEN_UNVERIFIED_GLUE 630
+#define VAR_LOG_TIME_ISO 631
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -779,7 +819,7 @@ union YYSTYPE
 
 	char*	str;
 
-#line 783 "util/configparser.h"
+#line 823 "util/configparser.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
